@@ -11,19 +11,17 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import eventlet
-eventlet.monkey_patch()
-
-import copy
 import json
-import mock
 import os
 import sys
 import tempfile
 import unittest
+from unittest import mock
 
-from ironic_inspector.common import swift
+import eventlet
+eventlet.monkey_patch()
 from ironic_inspector import introspection_state as istate
+from ironic_inspector import process
 from ironic_inspector.test import functional
 from keystoneauth1 import session as ks_session
 from keystoneauth1 import token_endpoint
@@ -40,7 +38,6 @@ class TestV1PythonAPI(functional.Base):
                                          token='token')
         self.session = ks_session.Session(self.auth)
         self.client = client.ClientV1(session=self.session)
-        functional.cfg.CONF.set_override('store_data', 'none', 'processing')
 
     def my_status_index(self, statuses):
         my_status = self._fake_status()
@@ -49,8 +46,8 @@ class TestV1PythonAPI(functional.Base):
     def test_introspect_get_status(self):
         self.client.introspect(self.uuid)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                              'reboot')
+        self.cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                              'rebooting')
 
         status = self.client.get_status(self.uuid)
         self.check_status(status, finished=False, state=istate.States.waiting)
@@ -59,10 +56,10 @@ class TestV1PythonAPI(functional.Base):
         self.assertEqual({'uuid': self.uuid}, res)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
 
-        self.assertCalledWithPatch(self.patch, self.cli.node.update)
-        self.cli.port.create.assert_called_once_with(
+        self.assertCalledWithPatch(self.patch, self.cli.patch_node)
+        self.cli.create_port.assert_called_once_with(
             node_uuid=self.uuid, address='11:22:33:44:55:66',
-            pxe_enabled=True, extra={})
+            is_pxe_enabled=True, extra={})
 
         status = self.client.get_status(self.uuid)
         self.check_status(status, finished=True, state=istate.States.finished)
@@ -70,8 +67,8 @@ class TestV1PythonAPI(functional.Base):
     def test_introspect_list_statuses(self):
         self.client.introspect(self.uuid)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                              'reboot')
+        self.cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                              'rebooting')
 
         statuses = self.client.list_statuses()
         my_status = statuses[self.my_status_index(statuses)]
@@ -82,10 +79,10 @@ class TestV1PythonAPI(functional.Base):
         self.assertEqual({'uuid': self.uuid}, res)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
 
-        self.assertCalledWithPatch(self.patch, self.cli.node.update)
-        self.cli.port.create.assert_called_once_with(
+        self.assertCalledWithPatch(self.patch, self.cli.patch_node)
+        self.cli.create_port.assert_called_once_with(
             node_uuid=self.uuid, address='11:22:33:44:55:66',
-            pxe_enabled=True, extra={})
+            is_pxe_enabled=True, extra={})
 
         statuses = self.client.list_statuses()
         my_status = statuses[self.my_status_index(statuses)]
@@ -117,15 +114,10 @@ class TestV1PythonAPI(functional.Base):
         status = self.client.get_status(self.uuid)
         self.check_status(status, finished=True, state=istate.States.finished)
 
-    @mock.patch.object(swift, 'store_introspection_data', autospec=True)
-    @mock.patch.object(swift, 'get_introspection_data', autospec=True)
-    def test_reprocess_stored_introspection_data(self, get_mock,
-                                                 store_mock):
-        functional.cfg.CONF.set_override('store_data', 'swift', 'processing')
+    def test_reprocess_stored_introspection_data(self):
         port_create_call = mock.call(node_uuid=self.uuid,
                                      address='11:22:33:44:55:66',
-                                     pxe_enabled=True, extra={})
-        get_mock.return_value = json.dumps(self.data)
+                                     is_pxe_enabled=True, extra={})
 
         # assert reprocessing doesn't work before introspection
         self.assertRaises(client.ClientError, self.client.reprocess,
@@ -133,8 +125,8 @@ class TestV1PythonAPI(functional.Base):
 
         self.client.introspect(self.uuid)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                              'reboot')
+        self.cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                              'rebooting')
         status = self.client.get_status(self.uuid)
         self.check_status(status, finished=False, state=istate.States.waiting)
 
@@ -144,10 +136,8 @@ class TestV1PythonAPI(functional.Base):
 
         status = self.client.get_status(self.uuid)
         self.check_status(status, finished=True, state=istate.States.finished)
-        self.cli.port.create.assert_has_calls([port_create_call],
+        self.cli.create_port.assert_has_calls([port_create_call],
                                               any_order=True)
-        self.assertFalse(get_mock.called)
-        self.assertTrue(store_mock.called)
 
         res = self.client.reprocess(self.uuid)
         self.assertEqual(202, res.status_code)
@@ -155,12 +145,9 @@ class TestV1PythonAPI(functional.Base):
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
         self.check_status(status, finished=True, state=istate.States.finished)
 
-        self.cli.port.create.assert_has_calls([port_create_call,
+        self.cli.create_port.assert_has_calls([port_create_call,
                                                port_create_call],
                                               any_order=True)
-        self.assertTrue(get_mock.called)
-        # incoming, processing, reapplying data
-        self.assertEqual(3, store_mock.call_count)
 
     def test_abort_introspection(self):
         # assert abort doesn't work before introspect request
@@ -169,8 +156,8 @@ class TestV1PythonAPI(functional.Base):
 
         self.client.introspect(self.uuid)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                              'reboot')
+        self.cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                              'rebooting')
 
         status = self.client.get_status(self.uuid)
         self.check_status(status, finished=False, state=istate.States.waiting)
@@ -223,6 +210,7 @@ class TestV1PythonAPI(functional.Base):
         rule = {'conditions': [],
                 'actions': [{'action': 'fail', 'message': 'boom'}],
                 'description': 'Cool actions',
+                'scope': None,
                 'uuid': self.uuid}
         res = self.client.rules.from_json(rule)
         self.assertEqual(self.uuid, res['uuid'])
@@ -235,7 +223,8 @@ class TestV1PythonAPI(functional.Base):
         res = self.client.rules.get_all()
         self.assertEqual(rule['links'], res[0].pop('links'))
         self.assertEqual([{'uuid': self.uuid,
-                           'description': 'Cool actions'}],
+                           'description': 'Cool actions',
+                           'scope': None}],
                          res)
 
         self.client.rules.delete(self.uuid)
@@ -264,8 +253,7 @@ class TestV1PythonAPI(functional.Base):
 
 
 BASE_CMD = [os.path.join(sys.prefix, 'bin', 'openstack'),
-            '--os-auth-type', 'token_endpoint', '--os-token', 'fake',
-            '--os-url', 'http://127.0.0.1:5050']
+            '--os-auth-type', 'none', '--os-endpoint', 'http://127.0.0.1:5050']
 
 
 class BaseCLITest(functional.Base):
@@ -296,8 +284,6 @@ class BaseCLITest(functional.Base):
 
 class TestCLI(BaseCLITest):
     def setup_lldp(self):
-        functional.cfg.CONF.set_override('store_data', 'swift', 'processing')
-
         self.all_interfaces = {
             'eth1': {'mac': self.macs[0], 'ip': self.ips[0],
                      'client_id': None, 'lldp_processed':
@@ -332,23 +318,24 @@ class TestCLI(BaseCLITest):
         return fake_status
 
     def test_cli_negative(self):
+        msg_missing_param = 'the following arguments are required'
         err = self.run_cli('start', expect_error=True)
-        self.assertIn('too few arguments', err)
+        self.assertIn(msg_missing_param, err)
         err = self.run_cli('status', expect_error=True)
-        self.assertIn('too few arguments', err)
+        self.assertIn(msg_missing_param, err)
         err = self.run_cli('rule', 'show', 'uuid', expect_error=True)
         self.assertIn('not found', err)
         err = self.run_cli('rule', 'delete', 'uuid', expect_error=True)
         self.assertIn('not found', err)
 
         err = self.run_cli('interface', 'list', expect_error=True)
-        self.assertIn('too few arguments', err)
+        self.assertIn(msg_missing_param, err)
 
     def test_introspect_get_status(self):
         self.run_cli('start', self.uuid)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                              'reboot')
+        self.cli.set_node_power_state.assert_called_once_with(self.uuid,
+                                                              'rebooting')
 
         status = self.run_cli('status', self.uuid, parse_json=True)
         self.check_status(status, finished=False, state=istate.States.waiting)
@@ -357,10 +344,10 @@ class TestCLI(BaseCLITest):
         self.assertEqual({'uuid': self.uuid}, res)
         eventlet.greenthread.sleep(functional.DEFAULT_SLEEP)
 
-        self.assertCalledWithPatch(self.patch, self.cli.node.update)
-        self.cli.port.create.assert_called_once_with(
+        self.assertCalledWithPatch(self.patch, self.cli.patch_node)
+        self.cli.create_port.assert_called_once_with(
             node_uuid=self.uuid, address='11:22:33:44:55:66',
-            pxe_enabled=True, extra={})
+            is_pxe_enabled=True, extra={})
 
         status = self.run_cli('status', self.uuid, parse_json=True)
         self.check_status(status, finished=True, state=istate.States.finished)
@@ -372,13 +359,15 @@ class TestCLI(BaseCLITest):
         rule = {'conditions': [],
                 'actions': [{'action': 'fail', 'message': 'boom'}],
                 'description': 'Cool actions',
+                'scope': None,
                 'uuid': self.uuid}
-        with tempfile.NamedTemporaryFile() as fp:
+        with tempfile.NamedTemporaryFile(mode='w') as fp:
             json.dump(rule, fp)
             fp.flush()
             res = self.run_cli('rule', 'import', fp.name, parse_json=True)
 
-        self.assertEqual([{'UUID': self.uuid, 'Description': 'Cool actions'}],
+        self.assertEqual([{'UUID': self.uuid,
+                           'Description': 'Cool actions'}],
                          res)
 
         res = self.run_cli('rule', 'show', self.uuid, parse_json=True)
@@ -393,7 +382,7 @@ class TestCLI(BaseCLITest):
         res = self.run_cli('rule', 'list', parse_json=True)
         self.assertEqual([], res)
 
-        with tempfile.NamedTemporaryFile() as fp:
+        with tempfile.NamedTemporaryFile(mode='w') as fp:
             rule.pop('uuid')
             json.dump([rule, rule], fp)
             fp.flush()
@@ -403,10 +392,10 @@ class TestCLI(BaseCLITest):
         res = self.run_cli('rule', 'list', parse_json=True)
         self.assertEqual([], res)
 
-    @mock.patch.object(swift, 'get_introspection_data', autospec=True)
+    @mock.patch.object(process, 'get_introspection_data', autospec=True)
     def test_interface_list(self, get_mock):
         self.setup_lldp()
-        get_mock.return_value = json.dumps(copy.deepcopy(self.data))
+        get_mock.return_value = json.dumps(self.data)
 
         expected_eth1 = {u'Interface': u'eth1',
                          u'MAC Address': u'11:22:33:44:55:66',
@@ -420,28 +409,26 @@ class TestCLI(BaseCLITest):
                          u'Switch Port VLAN IDs': [101, 102, 106]}
 
         res = self.run_cli('interface', 'list', self.uuid, parse_json=True)
-        res.sort()
-        self.assertEqual(expected_eth1, res[0])
-        self.assertEqual(expected_eth3, res[1])
+        self.assertIn(expected_eth1, res)
+        self.assertIn(expected_eth3, res)
 
         # Filter on vlan
         res = self.run_cli('interface', 'list', self.uuid, '--vlan', '106',
                            parse_json=True)
-        res.sort()
-        self.assertEqual(expected_eth3, res[0])
+        self.assertIn(expected_eth3, res)
 
         # Select fields
         res = self.run_cli('interface', 'list', self.uuid, '--fields',
                            'switch_port_mtu',
                            parse_json=True)
-        res.sort()
-        self.assertEqual({u'Switch Port MTU': 1514}, res[0])
-        self.assertEqual({u'Switch Port MTU': 9216}, res[1])
 
-    @mock.patch.object(swift, 'get_introspection_data', autospec=True)
+        self.assertIn({u'Switch Port MTU': 1514}, res)
+        self.assertIn({u'Switch Port MTU': 9216}, res)
+
+    @mock.patch.object(process, 'get_introspection_data', autospec=True)
     def test_interface_show(self, get_mock):
         self.setup_lldp()
-        get_mock.return_value = json.dumps(copy.deepcopy(self.data))
+        get_mock.return_value = json.dumps(self.data)
 
         res = self.run_cli('interface', 'show', self.uuid, "eth1",
                            parse_json=True)
@@ -460,6 +447,12 @@ class TestCLI(BaseCLITest):
 
         self.assertDictContainsSubset(expected, res)
 
+
 if __name__ == '__main__':
+    if len(sys.argv) > 1:
+        test_name = sys.argv[1]
+    else:
+        test_name = None
+
     with functional.mocked_server():
-        unittest.main(verbosity=2)
+        unittest.main(verbosity=2, defaultTest=test_name)
